import React, { useState, useEffect } from 'react';
import Info from './Info';
import * as Diagramming from '@mindfusion/diagramming';
import { DiagramView } from '@mindfusion/diagramming-react';

const onDiagramNodeCreated = (sender: Diagramming.Diagram, args: Diagramming.NodeEventArgs) => {
  var node = args.node;
  if (node instanceof Diagramming.TableNode) {
    node.text = "Table";
  }
  else if (node instanceof Diagramming.ContainerNode) {
    node.text = "Container";
    node.foldable = true;
  }
}

function MinApp() {
  const [diagram] = useState(new Diagramming.Diagram());
  const [behavior, setBehavior] = useState(Diagramming.Behavior.LinkShapes);
  const [nodes, setNodes] = useState(2);
  const [links, setLinks] = useState(1);

  const onDiagramChanged = (sender: Diagramming.DiagramView, args: any ) => {
    setNodes(sender.diagram.nodes.length);
    setLinks(sender.diagram.links.length);
  }

  const onBehaviorChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    setBehavior(+e.target.value);
  }

  useEffect(() => {
    // setup the diagram
    diagram.shadowsStyle = (Diagramming.ShadowsStyle.None);

    var shapeNode = diagram.factory.createShapeNode(20, 10, 50, 50);
    var tableNode = diagram.factory.createTableNode(100, 10, 50, 50);
    diagram.factory.createDiagramLink(shapeNode, tableNode);
  }, [diagram]);

  const props = {
    "allowInplaceEdit": true,
    "routeLinks": true,
    "showGrid": true,
    "backBrush": "lightcyan",
    "behavior": behavior
  };

  return (
    <div className="App">
      <div className="header">
        Behavior
        <select id="behavior" onChange={onBehaviorChange}>
          <option value="3">LinkShapes</option>
          <option value="4">LinkTables</option>
          <option value="11">LinkContainers</option>
          <option value="26">LinkFreeShapes</option>
          <option value="0">Modify</option>
        </select>

        <span>{"Nodes count: " + nodes}</span>
        <span>{"Links count: " + links}</span>
      </div>

      <div className="container">
        <div className="main">
          <DiagramView
            id="diagram"
            diagram={diagram}
            {...props}
            onDiagramChanged={(diagram, args) => onDiagramChanged(diagram, args)}
            onNodeCreated={(diagram, args) => onDiagramNodeCreated(diagram, args)} />
        </div>
        <div className="sidebar">
          <h1>About this sample</h1>
          <p>A sample page that shows the basic functionality of React DiagramView.</p>
          <Info />
        </div>
      </div>

      <div className="footer">
        <p>Copyright 2024 MindFusion LLC.</p>
      </div>

    </div>
  );

}


export default MinApp;
